@@ -46,27 +46,16 @@ phantomjs <- function(port = 4567L, version = "2.1.1", check = TRUE,
   if(retcommand){
     return(paste(c(phantomversion[["path"]], args), collapse = " "))
   }
-  errTfile <- tempfile(fileext = ".txt")
-  write(character(), errTfile)
-  outTfile <- tempfile(fileext = ".txt")
-  write(character(), outTfile)
-  phantomdrv <- if(identical(.Platform[["OS.type"]], "windows")){
-    tfile <- tempfile(fileext = ".bat")
-    write(paste(c(phantomversion[["path"]], args), collapse = " "), tfile)
-    subprocess::spawn_process(tfile, arguments = c(">", outTfile,
-                                                   "2>", errTfile))
-  }else{
-    subprocess::spawn_process(
-      phantomversion[["path"]], arguments = args
-    )
-  }
+  pfile <- pipe_files()
+  phantomdrv <- spawn_tofile(phantomversion[["path"]],
+                             args, pfile[["out"]], pfile[["err"]])
   if(!is.na(subprocess::process_return_code(phantomdrv))){
     stop("PhantomJS couldn't be started",
          subprocess::process_read(phantomdrv, "stderr"))
   }
   startlog <- generic_start_log(phantomdrv,
-                                outfile = outTfile,
-                                errfile = errTfile)
+                                outfile = pfile[["out"]],
+                                errfile = pfile[["err"]])
   if(length(startlog[["stdout"]]) >0){
     if(any(
       grepl("GhostDriver - main.fail.*sourceURL", startlog[["stdout"]])
@@ -80,15 +69,16 @@ phantomjs <- function(port = 4567L, version = "2.1.1", check = TRUE,
     process = phantomdrv,
     output = function(timeout = 0L){
       infun_read(phantomdrv, log, "stdout", timeout = timeout,
-                 outfile = outTfile, errfile = errTfile)
+                 outfile = pfile[["out"]], errfile = pfile[["err"]])
     },
     error = function(timeout = 0L){
       infun_read(phantomdrv, log, "stderr", timeout = timeout,
-                 outfile = outTfile, errfile = errTfile)
+                 outfile = pfile[["out"]], errfile = pfile[["err"]])
     },
     stop = function(){subprocess::process_kill(phantomdrv)},
     log = function(){
-      infun_read(phantomdrv, log, outfile = outTfile, errfile = errTfile)
+      infun_read(phantomdrv, log,
+                 outfile = pfile[["out"]], errfile = pfile[["err"]])
       as.list(log)
     }
   )
@@ -126,7 +116,7 @@ phantom_ver <- function(platform, version){
     mtch <- match(version, phantomver)
     if(is.na(mtch) || is.null(mtch)){
       stop("version requested doesnt match versions available = ",
-           paste(phantomver, collpase = ","))
+           paste(phantomver, collapse = ","))
     }
     phantomver[mtch]
   }
